storage

package
v2.12.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 15, 2025 License: Apache-2.0 Imports: 40 Imported by: 0

Documentation

Overview

Package storage needs to be documented.

TODO: document

Index

Constants

const (
	ChunkPrefix = "chunk/"
)

Variables

This section is empty.

Functions

func GlobLiteralPrefix added in v2.10.0

func GlobLiteralPrefix(glob string) string

func NewTestFilesetClient added in v2.12.0

func NewTestFilesetClient(t testing.TB, s *Server) storage.FilesetClient

func ValidateFilename added in v2.10.0

func ValidateFilename(p string) error

Types

type Env

type Env struct {
	DB     *pachsql.DB
	Bucket *blob.Bucket
	Config pachconfig.StorageConfiguration
}

type Server

type Server struct {
	storage.UnimplementedFilesetServer
	Filesets *fileset.Storage
	Chunks   *chunk.Storage
	Tracker  track.Tracker
}

Server contains the storage layer servers.

func New

func New(ctx context.Context, env Env) (*Server, error)

New creates a new Server

func NewTestServer added in v2.12.0

func NewTestServer(t testing.TB, db *pachsql.DB) *Server

func (*Server) ComposeFileset added in v2.10.0

func (*Server) CreateFileset added in v2.10.0

func (s *Server) CreateFileset(server storage.Fileset_CreateFilesetServer) error

func (*Server) ReadFileset added in v2.10.0

func (s *Server) ReadFileset(request *storage.ReadFilesetRequest, server storage.Fileset_ReadFilesetServer) error

ReadFileset is not properly documented.

  • TODO: Add file filter error types.
  • TODO: document.

func (*Server) ReadFilesetCDR added in v2.11.0

func (s *Server) ReadFilesetCDR(request *storage.ReadFilesetRequest, server storage.Fileset_ReadFilesetCDRServer) error

func (*Server) RenewFileset added in v2.10.0

func (s *Server) RenewFileset(ctx context.Context, request *storage.RenewFilesetRequest) (*emptypb.Empty, error)

RenewFileset is not properly documented.

  • TODO: We should be able to use this and potentially others directly in PFS.
  • TODO: Document.

func (*Server) ShardFileset added in v2.10.0

Directories

Path Synopsis
Package chunk provides access to data through content-addressed chunks.
Package chunk provides access to data through content-addressed chunks.
Package fileset provides access to files through file sets.
Package fileset provides access to files through file sets.
index
Package index provides access to files through multilevel indexes.
Package index provides access to files through multilevel indexes.
Package kv provides a Key-Value Store interface and a few implementations.
Package kv provides a Key-Value Store interface and a few implementations.
Package metrics implements storage metrics.
Package metrics implements storage metrics.
Package renew needs to be documented.
Package renew needs to be documented.
Package track implements a tracker.
Package track implements a tracker.

Jump to