license

package
v2.12.0-alpha.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 4, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package license implements the license server.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddClusterClientIdColumn

func AddClusterClientIdColumn(ctx context.Context, tx *pachsql.Tx) error

AddClusterClientIdColumn adds a client ID column to the clusters table.

DO NOT MODIFY THIS FUNCTION IT HAS BEEN USED IN A RELEASED MIGRATION

func AddUserContextsToClustersTable

func AddUserContextsToClustersTable(ctx context.Context, tx *pachsql.Tx) error

AddUserContextsToClustersTable adds user contexts to the clusters table.

DO NOT MODIFY THIS FUNCTION IT HAS BEEN USED IN A RELEASED MIGRATION

func CreateClustersTableV0

func CreateClustersTableV0(ctx context.Context, tx *pachsql.Tx) error

CreateClustersTableV0 sets up the postgres table which tracks active clusters.

DO NOT MODIFY THIS FUNCTION IT HAS BEEN USED IN A RELEASED MIGRATION

Types

This section is empty.

Directories

Path Synopsis
Package cmds implements pachctl commands for the license service.
Package cmds implements pachctl commands for the license service.
Package server implements the license service gRPC server.
Package server implements the license service gRPC server.

Jump to